// 
// Copyright (C) 2007, NinjaTrader LLC <www.ninjatrader.com>.
// NinjaTrader reserves the right to modify or overwrite this NinjaScript component with each release.
//

#region Using declarations
using System;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.ComponentModel;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Reference sample demonstrating how to trim the length of the NinjaScript label.
    /// </summary>
    [Description("Reference sample demonstrating how to trim the length of the NinjaScript label.")]
    public class SampleLabelTrim : Indicator
    {
        #region Variables
		// Create four internal variables for use with our user-definable parameters in the "Properties" section.
        private int period 		= 5;
        private int interval 	= 10;
        private int smooth 		= 15;
        private int numStdDev 	= 2;
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            CalculateOnBarClose	= true;
            Overlay				= true;
            PriceTypeSupported	= false;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			/* Print a string at the bottom right showing all the values of our user-definable parameters.
			The use of "\n" creates a new line in our output. */
			DrawTextFixed("Period", "Period: " + Period + "\nInterval: " + Interval + "\nSmooth: " + Smooth + "\nStdDev: " + NumStdDev, TextPosition.BottomRight);
        }

		// In order to trim the indicator's label we need to override the ToString() method.
		public override string ToString()
		{
			/* We return a label consisting of only the parameters we want to include. If we did not
			override this method we would have a label with all four parameters. In this example we will
			be left with only the parameters "Period" and "Interval". */
			return Name + "(" + Period + "," + Interval + ")";
		}
		
        #region Properties
		// Create our four user-definable variables.
        [Description("Numbers of bars used for calculations")]
        [Category("Parameters")]
        public int Period
        {
            get { return period; }
            set { period = Math.Max(1, value); }
        }

        [Description("Numbers of bars used for calculations")]
        [Category("Parameters")]
        public int Interval
        {
            get { return interval; }
            set { interval = Math.Max(1, value); }
        }

        [Description("Periods to use for smoothing")]
        [Category("Parameters")]
        public int Smooth
        {
            get { return smooth; }
            set { smooth = Math.Max(1, value); }
        }

        [Description("Number of standard deviations")]
        [Category("Parameters")]
        public int NumStdDev
        {
            get { return numStdDev; }
            set { numStdDev = Math.Max(1, value); }
        }
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private SampleLabelTrim[] cacheSampleLabelTrim = null;

        private static SampleLabelTrim checkSampleLabelTrim = new SampleLabelTrim();

        /// <summary>
        /// Reference sample demonstrating how to trim the length of the NinjaScript label.
        /// </summary>
        /// <returns></returns>
        public SampleLabelTrim SampleLabelTrim(int interval, int numStdDev, int period, int smooth)
        {
            return SampleLabelTrim(Input, interval, numStdDev, period, smooth);
        }

        /// <summary>
        /// Reference sample demonstrating how to trim the length of the NinjaScript label.
        /// </summary>
        /// <returns></returns>
        public SampleLabelTrim SampleLabelTrim(Data.IDataSeries input, int interval, int numStdDev, int period, int smooth)
        {
            checkSampleLabelTrim.Interval = interval;
            interval = checkSampleLabelTrim.Interval;
            checkSampleLabelTrim.NumStdDev = numStdDev;
            numStdDev = checkSampleLabelTrim.NumStdDev;
            checkSampleLabelTrim.Period = period;
            period = checkSampleLabelTrim.Period;
            checkSampleLabelTrim.Smooth = smooth;
            smooth = checkSampleLabelTrim.Smooth;

            if (cacheSampleLabelTrim != null)
                for (int idx = 0; idx < cacheSampleLabelTrim.Length; idx++)
                    if (cacheSampleLabelTrim[idx].Interval == interval && cacheSampleLabelTrim[idx].NumStdDev == numStdDev && cacheSampleLabelTrim[idx].Period == period && cacheSampleLabelTrim[idx].Smooth == smooth && cacheSampleLabelTrim[idx].EqualsInput(input))
                        return cacheSampleLabelTrim[idx];

            SampleLabelTrim indicator = new SampleLabelTrim();
            indicator.SetUp();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.Interval = interval;
            indicator.NumStdDev = numStdDev;
            indicator.Period = period;
            indicator.Smooth = smooth;

            SampleLabelTrim[] tmp = new SampleLabelTrim[cacheSampleLabelTrim == null ? 1 : cacheSampleLabelTrim.Length + 1];
            if (cacheSampleLabelTrim != null)
                cacheSampleLabelTrim.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheSampleLabelTrim = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Reference sample demonstrating how to trim the length of the NinjaScript label.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.SampleLabelTrim SampleLabelTrim(int interval, int numStdDev, int period, int smooth)
        {
            return _indicator.SampleLabelTrim(Input, interval, numStdDev, period, smooth);
        }

        /// <summary>
        /// Reference sample demonstrating how to trim the length of the NinjaScript label.
        /// </summary>
        /// <returns></returns>
        public Indicator.SampleLabelTrim SampleLabelTrim(Data.IDataSeries input, int interval, int numStdDev, int period, int smooth)
        {
            return _indicator.SampleLabelTrim(input, interval, numStdDev, period, smooth);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Reference sample demonstrating how to trim the length of the NinjaScript label.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.SampleLabelTrim SampleLabelTrim(int interval, int numStdDev, int period, int smooth)
        {
            return _indicator.SampleLabelTrim(Input, interval, numStdDev, period, smooth);
        }

        /// <summary>
        /// Reference sample demonstrating how to trim the length of the NinjaScript label.
        /// </summary>
        /// <returns></returns>
        public Indicator.SampleLabelTrim SampleLabelTrim(Data.IDataSeries input, int interval, int numStdDev, int period, int smooth)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.SampleLabelTrim(input, interval, numStdDev, period, smooth);
        }

    }
}
#endregion
